Documentation
¶
Index ¶
- func CalculateDirectorySize(rootPath string) (int64, error)
- func GenerateRandomString(stringLength int) string
- func GetMountPoint() string
- func IgnoreContainer(container explorers.Container, filter map[string]string) bool
- func IncludeContainer(container explorers.Container, filter map[string]string) bool
- func PathExists(path string) (bool, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateDirectorySize ¶
CalculateDirectorySize calculates the total size in bytes of all regular files within the given rootPath. It follows symbolic links for files to count the target's size. It does not follow symbolic links for directories during traversal. Broken symbolic links are skipped.
func GenerateRandomString ¶
GenerateRandomString creates a random string of a fixed length (6 characters).
func GetMountPoint ¶
func GetMountPoint() string
func IgnoreContainer ¶
func IncludeContainer ¶
func PathExists ¶
PathExists returns true of specified file or directory exists. If symlink is provided, it returns error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.